Flask-MongoAlchemy
==================

`Flask <http://flask.pocoo.org>`_ support for `MongoDB <http://mongodb.org>`_ using `MongoAlchemy <http://mongoalchemy.org>`_.

Documentation
+++++++++++++

If you want to get started, check the `example sourcecode <http://github.com/cobrateam/flask-mongoalchemy/tree/master/examples>`_ out.

    For full documentation, see the online docs at: `<http://packages.python.org/Flask-MongoAlchemy/>`_.

Development
+++++++++++

* Source hosted at `Github <http://github.com/cobrateam/flask-mongoalchemy>`_
* Report issues on `Github Issues <http://github.com/cobrateam/flask-mongoalchemy/issues>`_

Bootstraping the development environment
----------------------------------------

If you are using a virtualenv, bootstrap your development environment by running:

::

    $ make bootstrap

Running tests
-------------

With all dependencies installed (after bootstrap development env), just run:

::

    $ make test

Community
---------

#cobrateam on chanel irc.freenode.net

Changelog
+++++++++

Flask-MongoAlchemy 0.5.3
------------------------

 * [bugfix] fixed a bug on setup.py

Flask-MongoAlchemy 0.5.2
------------------------

 * added a configuration value to do user authentication per server or per database
 * [bugfix] fixed server based authentication

Flask-MongoAlchemy 0.5.1
------------------------

 * [bugfix] fixing the subpackage structure

Flask-MongoAlchemy 0.5
----------------------

 * Capability to deal with multiple Mongo sessions

Flask-MongoAlchemy 0.4.3
------------------------

 * [bugfix] added database to MongoDB URI for authenticated connectinos

Flask-MongoAlchemy 0.4.2
------------------------

 * Fixed pymongo dependency in setup.py

Flask-MongoAlchemy 0.4.1
------------------------

 * MongoAlchemy 0.9 as dependency
 * [bugfix] safe session operations on connect, save and remove

Flask-MongoAlchemy 0.4
----------------------

 * Documentation improvements
 * Support for safe or unsafe sessions and operations

Flask-MongoAlchemy 0.3.3
------------------------

 * Fixed dependencies on ``setup.py``

Flask-MongoAlchemy 0.3.2
------------------------

 * Compability with Flask 0.7

Flask-MongoAlchemy 0.3.1
------------------------

 * [bugfix] method ``get`` on ``Query`` objects was never returning the object

Flask-MongoAlchemy 0.3
----------------------

 * Introduced update queries support

Flask-MongoAlchemy 0.2
----------------------

* Reverse compatibility broken on ``Document`` class. The ``get()`` method was moved to ``BaseQuery`` class.
  Here the old code, on version ``0.1``: ::

    >>> Document.get(mongo_id)

  And the new code, on version ``0.2``: ::

    >>> Document.query.get(mongo_id)

* Added ``get_or_404``, ``first_or_404`` and ``paginate`` methods on ``BaseQuery`` class. Check the `documentation <http://packages.python.org/Flask-MongoAlchemy>`_ to know how to use them :)
